@@ -1,10 +1,10 @@
-recluster.node.strength <-function (mat, dist="simpson", tr=100, method="average"){
+recluster.node.strength <-function (mat, phylo=NULL, dist="simpson", tr=100, method="average"){
 	out<-NULL
-	treesstr<-(as.phylo(hclust(recluster.dist(mat,dist),method=method)))
+	treesstr<-(as.phylo(hclust(recluster.dist(mat,phylo,dist),method=method)))
 	tree1<-treesstr
 	for (cons in 1 : 6){
 		p<-0.5+((cons-1)*0.1)
-		treesstr[[cons]]<-recluster.cons(mat,dist=dist,tr=tr,method=method,p=p)
+		treesstr[[cons]]<-recluster.cons(mat,phylo,dist=dist,tr=tr,method=method,p=p)
 	}
 	btr2 <- .compressTipLabel(treesstr)
 	tr2 <- recluster.check(tree1, attr(btr2, "TipLabel"))
